@@ -22,32 +22,34 @@ declare(strict_types=1);
  *
  */
 
-namespace OCA\Spreed\Controller;
+namespace OCA\Talk\Controller;
 
-use OCA\Spreed\Config;
-use OCA\Spreed\Exceptions\RoomNotFoundException;
-use OCA\Spreed\Exceptions\ParticipantNotFoundException;
-use OCA\Spreed\Manager;
-use OCA\Spreed\Participant;
-use OCA\Spreed\Room;
-use OCA\Spreed\Signaling\Messages;
-use OCA\Spreed\TalkSession;
+use OCA\Talk\Config;
+use OCA\Talk\Events\SignalingEvent;
+use OCA\Talk\Exceptions\RoomNotFoundException;
+use OCA\Talk\Exceptions\ParticipantNotFoundException;
+use OCA\Talk\Manager;
+use OCA\Talk\Participant;
+use OCA\Talk\Room;
+use OCA\Talk\Signaling\Messages;
+use OCA\Talk\TalkSession;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\OCSController;
 use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IDBConnection;
 use OCP\IRequest;
 use OCP\IUser;
 use OCP\IUserManager;
-use Symfony\Component\EventDispatcher\EventDispatcherInterface;
-use Symfony\Component\EventDispatcher\GenericEvent;
 
 class SignalingController extends OCSController {
 
 	/** @var int */
 	private const PULL_MESSAGES_TIMEOUT = 30;
 
+	public const EVENT_BACKEND_SIGNALING_ROOMS = self::class . '::signalingBackendRoom';
+
 	/** @var Config */
 	private $config;
 	/** @var TalkSession */
@@ -60,7 +62,7 @@ class SignalingController extends OCSController {
 	private $messages;
 	/** @var IUserManager */
 	private $userManager;
-	/** @var EventDispatcherInterface */
+	/** @var IEventDispatcher */
 	private $dispatcher;
 	/** @var ITimeFactory */
 	private $timeFactory;
@@ -75,7 +77,7 @@ class SignalingController extends OCSController {
 								IDBConnection $connection,
 								Messages $messages,
 								IUserManager $userManager,
-								EventDispatcherInterface $dispatcher,
+								IEventDispatcher $dispatcher,
 								ITimeFactory $timeFactory,
 								?string $UserId) {
 		parent::__construct($appName, $request);
@@ -250,9 +252,9 @@ class SignalingController extends OCSController {
 	/**
 	 * Check if the current request is coming from an allowed backend.
 	 *
-	 * The backends are sending the custom header "Spreed-Signaling-Random"
+	 * The backends are sending the custom header "Talk-Signaling-Random"
 	 * containing at least 32 bytes random data, and the header
-	 * "Spreed-Signaling-Checksum", which is the SHA256-HMAC of the random data
+	 * "Talk-Signaling-Checksum", which is the SHA256-HMAC of the random data
 	 * and the body of the request, calculated with the shared secret from the
 	 * configuration.
 	 *
@@ -426,13 +428,8 @@ class SignalingController extends OCSController {
 			}
 		}
 
-		$event = new GenericEvent($room, [
-			'action' => $action,
-			'participant' => $participant,
-			'sessionid' => $sessionId,
-			'userid' => $userId,
-		]);
-		$this->dispatcher->dispatch(self::class . '::signalingBackendRoom', $event);
+		$event = new SignalingEvent($room, $participant, $action);
+		$this->dispatcher->dispatch(self::EVENT_BACKEND_SIGNALING_ROOMS, $event);
 
 		$response = [
 			'type' => 'room',
@@ -445,8 +442,8 @@ class SignalingController extends OCSController {
 				],
 			],
 		];
-		if ($event->hasArgument('roomSession')) {
-			$response['room']['session'] = $event->getArgument('roomSession');
+		if ($event->getSession()) {
+			$response['room']['session'] = $event->getSession();
 		}
 		return new DataResponse($response);
 	}
