@@ -20,20 +20,28 @@ declare(strict_types=1);
  *
  */
 
-namespace OCA\Spreed\Signaling;
+namespace OCA\Talk\Signaling;
 
-use OCA\Spreed\Chat\ChatManager;
-use OCA\Spreed\Config;
-use OCA\Spreed\GuestManager;
-use OCA\Spreed\Participant;
-use OCA\Spreed\Room;
-use OCP\IUser;
-use Symfony\Component\EventDispatcher\EventDispatcherInterface;
-use Symfony\Component\EventDispatcher\GenericEvent;
+use OCA\Talk\Chat\ChatManager;
+use OCA\Talk\Config;
+use OCA\Talk\Events\AddParticipantsEvent;
+use OCA\Talk\Events\ChatEvent;
+use OCA\Talk\Events\ChatParticipantEvent;
+use OCA\Talk\Events\ModifyLobbyEvent;
+use OCA\Talk\Events\ModifyParticipantEvent;
+use OCA\Talk\Events\ModifyRoomEvent;
+use OCA\Talk\Events\ParticipantEvent;
+use OCA\Talk\Events\RemoveParticipantEvent;
+use OCA\Talk\Events\RemoveUserEvent;
+use OCA\Talk\Events\RoomEvent;
+use OCA\Talk\GuestManager;
+use OCA\Talk\Participant;
+use OCA\Talk\Room;
+use OCP\EventDispatcher\IEventDispatcher;
 
 class Listener {
 
-	public static function register(EventDispatcherInterface $dispatcher): void {
+	public static function register(IEventDispatcher $dispatcher): void {
 		self::registerInternalSignaling($dispatcher);
 		self::registerExternalSignaling($dispatcher);
 	}
@@ -44,32 +52,28 @@ class Listener {
 		return empty($config->getSignalingServers());
 	}
 
-	protected static function registerInternalSignaling(EventDispatcherInterface $dispatcher): void {
-		$listener = function(GenericEvent $event) {
+	protected static function registerInternalSignaling(IEventDispatcher $dispatcher): void {
+		$listener = static function(RoomEvent $event) {
 			if (!self::isUsingInternalSignaling()) {
 				return;
 			}
 
-			/** @var Room $room */
-			$room = $event->getSubject();
-
 			/** @var Messages $messages */
 			$messages = \OC::$server->query(Messages::class);
-			$messages->addMessageForAllParticipants($room, 'refresh-participant-list');
+			$messages->addMessageForAllParticipants($event->getRoom(), 'refresh-participant-list');
 		};
-		$dispatcher->addListener(Room::class . '::postJoinRoom', $listener);
-		$dispatcher->addListener(Room::class . '::postJoinRoomGuest', $listener);
-		$dispatcher->addListener(Room::class . '::postSessionJoinCall', $listener);
-		$dispatcher->addListener(Room::class . '::postSessionLeaveCall', $listener);
-		$dispatcher->addListener(GuestManager::class . '::updateName', $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_ROOM_CONNECT, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_GUEST_CONNECT, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_SESSION_JOIN_CALL, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_SESSION_LEAVE_CALL, $listener);
+		$dispatcher->addListener(GuestManager::EVENT_AFTER_NAME_UPDATE, $listener);
 
-		$listener = function(GenericEvent $event) {
+		$listener = static function(ParticipantEvent $event) {
 			if (!self::isUsingInternalSignaling()) {
 				return;
 			}
 
-			/** @var Room $room */
-			$room = $event->getSubject();
+			$room = $event->getRoom();
 
 			/** @var Messages $messages */
 			$messages = \OC::$server->query(Messages::class);
@@ -79,23 +83,24 @@ class Listener {
 			// no longer in the room, so the message needs to be explicitly
 			// added for the participant.
 			/** @var Participant $participant */
-			$participant = $event->getArgument('participant');
+			$participant = $event->getParticipant();
 			if ($participant->getSessionId() !== '0') {
 				$messages->addMessage($participant->getSessionId(), $participant->getSessionId(), 'refresh-participant-list');
 			}
 		};
-		$dispatcher->addListener(Room::class . '::postRemoveUser', $listener);
-		$dispatcher->addListener(Room::class . '::postRemoveBySession', $listener);
-		$dispatcher->addListener(Room::class . '::postUserDisconnectRoom', $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_USER_REMOVE, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_PARTICIPANT_REMOVE, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_ROOM_DISCONNECT, $listener);
 
-		$listener = function(GenericEvent $event) {
+		$listener = static function(RoomEvent $event) {
+			$room = $event->getRoom();
 			if (!self::isUsingInternalSignaling()) {
 				return;
 			}
 
 			/** @var Messages $messages */
 			$messages = \OC::$server->query(Messages::class);
-			$participants = $event->getArgument('participants');
+			$participants = $room->getParticipantsLegacy();
 			foreach ($participants['users'] as $participant) {
 				$messages->addMessage($participant['sessionId'], $participant['sessionId'], 'refresh-participant-list');
 			}
@@ -103,11 +108,11 @@ class Listener {
 				$messages->addMessage($participant['sessionId'], $participant['sessionId'], 'refresh-participant-list');
 			}
 		};
-		$dispatcher->addListener(Room::class . '::postDeleteRoom', $listener);
+		$dispatcher->addListener(Room::EVENT_BEFORE_ROOM_DELETE, $listener);
 	}
 
-	protected static function registerExternalSignaling(EventDispatcherInterface $dispatcher): void {
-		$dispatcher->addListener(Room::class . '::postAddUsers', function(GenericEvent $event) {
+	protected static function registerExternalSignaling(IEventDispatcher $dispatcher): void {
+		$dispatcher->addListener(Room::EVENT_AFTER_USERS_ADD, static function(AddParticipantsEvent $event) {
 			if (self::isUsingInternalSignaling()) {
 				return;
 			}
@@ -115,11 +120,9 @@ class Listener {
 			/** @var BackendNotifier $notifier */
 			$notifier = \OC::$server->query(BackendNotifier::class);
 
-			$room = $event->getSubject();
-			$participants= $event->getArgument('users');
-			$notifier->roomInvited($room, $participants);
+			$notifier->roomInvited($event->getRoom(), $event->getParticipants());
 		});
-		$dispatcher->addListener(Room::class . '::postSetName', function(GenericEvent $event) {
+		$listener = static function(RoomEvent $event) {
 			if (self::isUsingInternalSignaling()) {
 				return;
 			}
@@ -127,10 +130,15 @@ class Listener {
 			/** @var BackendNotifier $notifier */
 			$notifier = \OC::$server->query(BackendNotifier::class);
 
-			$room = $event->getSubject();
-			$notifier->roomModified($room);
-		});
-		$dispatcher->addListener(Room::class . '::postSetParticipantType', function(GenericEvent $event) {
+			$notifier->roomModified($event->getRoom());
+		};
+		$dispatcher->addListener(Room::EVENT_AFTER_NAME_SET, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_PASSWORD_SET, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_TYPE_SET, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_READONLY_SET, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_LOBBY_STATE_SET, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_PARTICIPANT_TYPE_SET, $listener);
+		$dispatcher->addListener(Room::EVENT_BEFORE_ROOM_DELETE, static function(RoomEvent $event) {
 			if (self::isUsingInternalSignaling()) {
 				return;
 			}
@@ -138,37 +146,11 @@ class Listener {
 			/** @var BackendNotifier $notifier */
 			$notifier = \OC::$server->query(BackendNotifier::class);
 
-			$room = $event->getSubject();
-			// The type of a participant has changed, notify all participants
-			// so they can update the room properties.
-			$notifier->roomModified($room);
-		});
-		$dispatcher->addListener(Room::class . '::postSetParticipantTypeBySession', function(GenericEvent $event) {
-			if (self::isUsingInternalSignaling()) {
-				return;
-			}
-
-			/** @var BackendNotifier $notifier */
-			$notifier = \OC::$server->query(BackendNotifier::class);
-
-			$room = $event->getSubject();
-			// The type of a participant has changed, notify all participants
-			// so they can update the room properties.
-			$notifier->roomModified($room);
-		});
-		$dispatcher->addListener(Room::class . '::postDeleteRoom', function(GenericEvent $event) {
-			if (self::isUsingInternalSignaling()) {
-				return;
-			}
-
-			/** @var BackendNotifier $notifier */
-			$notifier = \OC::$server->query(BackendNotifier::class);
-
-			$room = $event->getSubject();
-			$participants = $event->getArgument('participants');
+			$room = $event->getRoom();
+			$participants = $room->getParticipantsLegacy();
 			$notifier->roomDeleted($room, $participants);
 		});
-		$dispatcher->addListener(Room::class . '::postRemoveUser', function(GenericEvent $event) {
+		$dispatcher->addListener(Room::EVENT_AFTER_USER_REMOVE, static function(RemoveUserEvent $event) {
 			if (self::isUsingInternalSignaling()) {
 				return;
 			}
@@ -176,11 +158,9 @@ class Listener {
 			/** @var BackendNotifier $notifier */
 			$notifier = \OC::$server->query(BackendNotifier::class);
 
-			$room = $event->getSubject();
-			$user = $event->getArgument('user');
-			$notifier->roomsDisinvited($room, [$user->getUID()]);
+			$notifier->roomsDisinvited($event->getRoom(), [$event->getUser()->getUID()]);
 		});
-		$dispatcher->addListener(Room::class . '::postRemoveBySession', function(GenericEvent $event) {
+		$dispatcher->addListener(Room::EVENT_AFTER_PARTICIPANT_REMOVE, static function(RemoveParticipantEvent $event) {
 			if (self::isUsingInternalSignaling()) {
 				return;
 			}
@@ -188,11 +168,10 @@ class Listener {
 			/** @var BackendNotifier $notifier */
 			$notifier = \OC::$server->query(BackendNotifier::class);
 
-			$room = $event->getSubject();
-			$participant = $event->getArgument('participant');
-			$notifier->roomSessionsRemoved($room, [$participant->getSessionId()]);
+			$notifier->roomSessionsRemoved($event->getRoom(), [$event->getParticipant()->getSessionId()]);
 		});
-		$dispatcher->addListener(Room::class . '::postSessionJoinCall', function(GenericEvent $event) {
+
+		$listener = static function(ModifyParticipantEvent $event) {
 			if (self::isUsingInternalSignaling()) {
 				return;
 			}
@@ -200,12 +179,16 @@ class Listener {
 			/** @var BackendNotifier $notifier */
 			$notifier = \OC::$server->query(BackendNotifier::class);
 
-			$room = $event->getSubject();
-			$sessionId = $event->getArgument('sessionId');
-			$flags = $event->getArgument('flags');
-			$notifier->roomInCallChanged($room, $flags, [$sessionId]);
-		});
-		$dispatcher->addListener(Room::class . '::postSessionLeaveCall', function(GenericEvent $event) {
+			$notifier->roomInCallChanged(
+				$event->getRoom(),
+				$event->getNewValue(),
+				[$event->getParticipant()->getSessionId()]
+			);
+		};
+		$dispatcher->addListener(Room::EVENT_AFTER_SESSION_JOIN_CALL, $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_SESSION_LEAVE_CALL, $listener);
+
+		$dispatcher->addListener(Room::EVENT_AFTER_GUESTS_CLEAN, static function(RoomEvent $event) {
 			if (self::isUsingInternalSignaling()) {
 				return;
 			}
@@ -213,37 +196,12 @@ class Listener {
 			/** @var BackendNotifier $notifier */
 			$notifier = \OC::$server->query(BackendNotifier::class);
 
-			$room = $event->getSubject();
-			$sessionId = $event->getArgument('sessionId');
-			$notifier->roomInCallChanged($room, Participant::FLAG_DISCONNECTED, [$sessionId]);
-		});
-		$dispatcher->addListener(Room::class . '::postRemoveBySession', function(GenericEvent $event) {
-			if (self::isUsingInternalSignaling()) {
-				return;
-			}
-
-			/** @var BackendNotifier $notifier */
-			$notifier = \OC::$server->query(BackendNotifier::class);
-
-			$room = $event->getSubject();
-			$participant = $event->getArgument('participant');
-			$notifier->participantsModified($room, [$participant->getSessionId()]);
-		});
-		$dispatcher->addListener(Room::class . '::postCleanGuests', function(GenericEvent $event) {
-			if (self::isUsingInternalSignaling()) {
-				return;
-			}
-
-			/** @var BackendNotifier $notifier */
-			$notifier = \OC::$server->query(BackendNotifier::class);
-
-			$room = $event->getSubject();
 			// TODO: The list of removed session ids should be passed through the event
 			// so the signaling server can optimize forwarding the message.
 			$sessionIds = [];
-			$notifier->participantsModified($room, $sessionIds);
+			$notifier->participantsModified($event->getRoom(), $sessionIds);
 		});
-		$dispatcher->addListener(GuestManager::class . '::updateName', function(GenericEvent $event) {
+		$dispatcher->addListener(GuestManager::EVENT_AFTER_NAME_UPDATE, static function(ModifyParticipantEvent $event) {
 			if (self::isUsingInternalSignaling()) {
 				return;
 			}
@@ -251,11 +209,9 @@ class Listener {
 			/** @var BackendNotifier $notifier */
 			$notifier = \OC::$server->query(BackendNotifier::class);
 
-			$room = $event->getSubject();
-			$sessionId = $event->getArgument('sessionId');
-			$notifier->participantsModified($room, [$sessionId]);
+			$notifier->participantsModified($event->getRoom(), [$event->getParticipant()->getSessionId()]);
 		});
-		$dispatcher->addListener(ChatManager::class . '::sendMessage', function(GenericEvent $event) {
+		$dispatcher->addListener(ChatManager::EVENT_AFTER_MESSAGE_SEND , static function(ChatParticipantEvent $event) {
 			if (self::isUsingInternalSignaling()) {
 				return;
 			}
@@ -263,7 +219,7 @@ class Listener {
 			/** @var BackendNotifier $notifier */
 			$notifier = \OC::$server->query(BackendNotifier::class);
 
-			$room = $event->getSubject();
+			$room = $event->getRoom();
 			$message = [
 				'type' => 'chat',
 				'chat' => [
@@ -272,7 +228,7 @@ class Listener {
 			];
 			$notifier->sendRoomMessage($room, $message);
 		});
-		$dispatcher->addListener(ChatManager::class . '::sendSystemMessage', function(GenericEvent $event) {
+		$dispatcher->addListener(ChatManager::EVENT_AFTER_SYSTEM_MESSAGE_SEND, static function(ChatEvent $event) {
 			if (self::isUsingInternalSignaling()) {
 				return;
 			}
@@ -280,7 +236,7 @@ class Listener {
 			/** @var BackendNotifier $notifier */
 			$notifier = \OC::$server->query(BackendNotifier::class);
 
-			$room = $event->getSubject();
+			$room = $event->getRoom();
 			$message = [
 				'type' => 'chat',
 				'chat' => [
